MadroidContainer class

Inheritance

Constructors

MadroidContainer({Key? key, bool visible = true, double height = 0.0, double width = 0.0, double margin = 0.0, double? marginTop, double? marginLeft, double? marginRight, double? marginBottom, double? marginVertical, double? marginHorizontal, double padding = 10.0, double? paddingTop, double? paddingLeft, double? paddingRight, double? paddingBottom, double? paddingVertical, double? paddingHorizontal, double border = 10.0, double? borderTop, double? borderLeft, double? borderRight, double? borderBottom, double? borderVertical, double? borderHorizontal, double radius = 0.0, double? radiusTop, double? radiusLeft, double? radiusRight, double? radiusBottom, double? radiusDiagonal, double? radiusInverseDiagonal, double? radiusTopLeft, double? radiusTopRight, double? radiusBottomLeft, double? radiusBottomRight, Color? color = kTransparent, Color borderColor = kTransparent, String image = '', ImageType imageType = ImageType.none, BoxFit imageFit = BoxFit.cover, double elevation = 0.0, GradientType gradientType = GradientType.none, List<Color> gradient = const <Color>[], BoxShape shape = BoxShape.rectangle, VoidCallback? onTap, VoidCallback? onLongPress, VoidCallback? onDoubleTap, Widget? child})
const

Properties

border double
final
borderBottom double?
final
borderColor Color
final
borderHorizontal double?
final
borderLeft double?
final
borderRight double?
final
borderTop double?
final
borderVertical double?
final
child Widget?
final
color Color?
final
elevation double
final
gradient List<Color>
final
gradientType GradientType
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
image String
final
imageFit BoxFit
final
imageType ImageType
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin double
final
marginBottom double?
final
marginHorizontal double?
final
marginLeft double?
final
marginRight double?
final
marginTop double?
final
marginVertical double?
final
onDoubleTap VoidCallback?
final
onLongPress VoidCallback?
final
onTap VoidCallback?
final
padding double
final
paddingBottom double?
final
paddingHorizontal double?
final
paddingLeft double?
final
paddingRight double?
final
paddingTop double?
final
paddingVertical double?
final
radius double
final
radiusBottom double?
final
radiusBottomLeft double?
final
radiusBottomRight double?
final
radiusDiagonal double?
final
radiusInverseDiagonal double?
final
radiusLeft double?
final
radiusRight double?
final
radiusTop double?
final
radiusTopLeft double?
final
radiusTopRight double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape BoxShape
final
visible bool
final
width double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited