MadroidResponsiveListView class

Inheritance

Constructors

MadroidResponsiveListView({Key? key, required int count, required List<Widget> children, Widget separator = kEmptyWidget, bool visible = true, ScrollController? controller, double spacing = 0.0, double margin = 0.0, double? marginTop, double? marginLeft, double? marginRight, double? marginBottom, double? marginVertical, double? marginHorizontal, double padding = 0.0, double? paddingTop, double? paddingLeft, double? paddingRight, double? paddingBottom, double? paddingVertical, double? paddingHorizontal, Axis scrollDirection = Axis.vertical, bool scroll = true, bool shrinkWrap = false, bool reverse = false})
const

Properties

children List<Widget>
final
controller ScrollController?
final
count int
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin double
final
marginBottom double?
final
marginHorizontal double?
final
marginLeft double?
final
marginRight double?
final
marginTop double?
final
marginVertical double?
final
padding double
final
paddingBottom double?
final
paddingHorizontal double?
final
paddingLeft double?
final
paddingRight double?
final
paddingTop double?
final
paddingVertical double?
final
reverse bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scroll bool
final
scrollDirection Axis
final
separator Widget
final
shrinkWrap bool
final
spacing double
final
visible bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited