MadroidText class

Inheritance

Constructors

MadroidText({Key? key, required String text, bool visible = true, double margin = 0.0, double? marginTop, double? marginLeft, double? marginRight, double? marginBottom, double? marginVertical, double? marginHorizontal, Color color = kWhiteColor, double? size, String? font, FontWeight weight = FontWeight.normal, TextOverflow? overflow, TextAlign align = TextAlign.justify, double? letterSpacing, double? wordSpacing, VoidCallback? onTap, VoidCallback? onLongPress, VoidCallback? onDoubleTap})
const

Properties

align TextAlign
final
color Color
final
font String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letterSpacing double?
final
margin double
final
marginBottom double?
final
marginHorizontal double?
final
marginLeft double?
final
marginRight double?
final
marginTop double?
final
marginVertical double?
final
onDoubleTap VoidCallback?
final
onLongPress VoidCallback?
final
onTap VoidCallback?
final
overflow TextOverflow?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final
text String
final
visible bool
final
weight FontWeight
final
wordSpacing double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited